import expect from 'expect';
import React, { PropTypes } from 'react';
import { Simulate } from 'react-addons-test-utils';
import { renderTest } from 'react-redux-provide-test-utils';
import { Test } from './components/index';
import providers from './providers/index';
import { darkTheme, lightTheme } from './themes/index';

const context = {
  providers,
  providedState: {
    theme: darkTheme,
    list: [
      {
        value: 'test'
      }
    ]
  }
};

const test = renderTest(Test, { ...context });

function getHeight(node) {
  const computedStyle = window.getComputedStyle(node, null);
  return computedStyle.getPropertyValue('height');
}

function getFontFamily(node) {
  const computedStyle = window.getComputedStyle(node, null);
  return computedStyle.getPropertyValue('font-family');
}

function getBgColor(node) {
  const computedStyle = window.getComputedStyle(node, null);
  return computedStyle.getPropertyValue('background-color');
}

function getColor(node) {
  const computedStyle = window.getComputedStyle(node, null);
  return computedStyle.getPropertyValue('color');
}

describe('react-redux-provide-theme', () => {
  it('should render correctly with initialized dark theme', () => {
    expect(document.getElementsByTagName('style').length).toBe(2);
    
    expect(test.node.tagName).toBe('DIV');
    expect(test.node.childNodes.length).toBe(1);

    expect(getHeight(document.body)).toBe('100%');
    expect(getFontFamily(document.body)).toBe('Droid Sans');

    expect(getBgColor(test.node)).toBe('rgb(0, 0, 0)');
    expect(getColor(test.node)).toBe('rgb(255, 255, 255)');

    expect(getBgColor(test.node.childNodes[0])).toBe('rgb(51, 51, 51)');
    expect(getColor(test.node.childNodes[0])).toBe('rgb(221, 221, 221)');
  });

  it('should render correctly upon switching to light theme', () => {
    test.wrappedInstance.props.setTheme(lightTheme);

    expect(document.getElementsByTagName('style').length).toBe(2);

    expect(test.node.tagName).toBe('DIV');
    expect(test.node.childNodes.length).toBe(1);

    expect(getHeight(document.body)).toBe('100%');
    expect(getFontFamily(document.body)).toBe('Droid Sans Mono');

    expect(getBgColor(test.node)).toBe('rgb(255, 255, 255)');
    expect(getColor(test.node)).toBe('rgb(0, 0, 0)');

    expect(getBgColor(test.node.childNodes[0])).toBe('rgb(221, 221, 221)');
    expect(getColor(test.node.childNodes[0])).toBe('rgb(51, 51, 51)');
  });
});
